<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Block_Js extends Creativestyle_AmazonCheckout_Block_Template
{
    const APP_JS_URL = 'creativestyle/amazon-pay.js';

    /**
     * Return URL of the frontend application JS file
     *
     * @return string
     * @api
     */
    public function getJsAppUrl() {
        if ($this->_getConfig()->isJsVersioningDisabled()) {
            return $this->getJsUrl(self::APP_JS_URL);
        }

        return $this->getJsUrl(sprintf('%s?v=%s', self::APP_JS_URL, $this->getVersion()));
    }

    /**
     * Return JS application configuration in JSON format
     *
     * @return string
     * @api
     */
    public function getAppConfig() {
        return $this->_jsonEncode(array(
            'merchantId' => $this->getMerchantId(),
            'clientId' => $this->getClientId(),
            'publicKeyId' => $this->getPublicKeyId(),
            'sandbox' => $this->isSandboxActive(),
            'currency' => $this->getLedgerCurrencyCode(),
            'language' => $this->getLanguage(),
            'urls' => array(
                'addToCart' => $this->getAddToCartUrl(),
                'createCheckoutSession' => $this->getCreateCheckoutSessionUrl(),
                'signInReturnUrl' => $this->getSignInReturnUrl(),
                'saveShippingMethod' => $this->getSaveShippingMethodUrl(),
                'saveOrderData' => $this->getSaveOrderDataUrl(),
                'placeOrder' => $this->getPlaceOrderUrl(),
                'couponPost' => $this->getCouponPostUrl(),
            ),
            'payButtonColor' => $this->getPayButtonColor(),
            'loginButtonColor' => $this->getLoginButtonColor(),
            'addToCartForm' => 'product_addtocart_form'
        ));
    }

    /**
     * Return JS application session data in JSON format
     *
     * @return string
     * @throws Creativestyle_AmazonCheckout_Exception_Runtime_Api
     * @api
     */
    public function getAppSession() {
        $loginPayload = stripcslashes($this->_getApi()->getSignInPayload(array('name', 'email', 'postalCode')));
        $loginPayload = str_replace('?___SID=S', '', $loginPayload);

        $payPayload = stripcslashes(json_encode($this->_getApi()->getCheckoutSessionPayload($this->getPresentmentCurrencyCode())));
        $payPayload = str_replace('?___SID=S', '', $payPayload);

        return $this->_jsonEncode(
            array_filter(
                array(
                    'checkoutSessionId' => $this->getCheckoutSessionId(),
                    'virtualOrder' => $this->isOrderVirtual(),
                    'login' => array(
                        'payload' => $loginPayload,
                        'signature' => $this->_getApi()->generateButtonSignature($loginPayload)
                    ),
                    'pay' => array(
                        'payload' => $payPayload,
                        'signature' => $this->_getApi()->generateButtonSignature($payPayload)
                    )
                ),
                function ($item) { return null !== $item; }
            )
        );
    }
}
