<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */
class Creativestyle_AmazonCheckout_Model_System_Config_Backend_PrivateKey extends Mage_Core_Model_Config_Data
{
    /**
     * @return Mage_Core_Model_Encryption
     */
    protected function _getEncryptionModel()
    {
        /** @var Mage_Core_Model_Encryption $encryption */
        $encryption = Mage::getSingleton('core/encryption');
        return $encryption;
    }

    /**
     * Return instance of Amazon Pay helper
     *
     * @return Creativestyle_AmazonCheckout_Helper_Data
     */
    protected function _getAmazonHelper()
    {
        /** @var Creativestyle_AmazonCheckout_Helper_Data $helper */
        $helper = Mage::helper('amazonpay');
        return $helper;
    }

    /**
     * Returns Magento admin session instance
     *
     * @return Mage_Adminhtml_Model_Session
     */
    protected function _getSession()
    {
        /** @var Mage_Adminhtml_Model_Session $session */
        $session = Mage::getModel('adminhtml/session');
        return $session;
    }

    /**
     * @return Mage_Core_Model_Abstract
     * @throws Exception
     */
    public function save()
    {
        $value = $this->getValue();

        $keyToValidate = $value ? $value : $this->_getEncryptionModel()->decrypt($this->getOldValue());
        if (!$this->_getAmazonHelper()->isPrivateKeyValid($keyToValidate)) {
            $this->_getSession()
                ->addError('Your Private Key does not seem valid. Please assure it is pasted correctly.');
        }

        if ($value) {
            $this->setValue(trim($value) ? $this->_getEncryptionModel()->encrypt(trim($value)) : null);
            return parent::save();
        }

        return $this;
    }
}
